input

package
v0.23.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AskYesNo

func AskYesNo(prompt string) (bool, error)

AskYesNo prompts the user with a yes/no question and returns their boolean answer.

func PickEntry

func PickEntry(store string, query string) (string, error)

PickEntry interactively selects an entry using a fuzzy finder.

func ReadNewPassword

func ReadNewPassword(confirm bool) (string, error)

ReadNewPassword prompts the user to input a new password, optionally asking for confirmation by re-entering it.

func SecureRead

func SecureRead(prompt string) (string, error)

Read a password without echo if standard input is a terminal.

Types

This section is empty.

Jump to